from typing import Any, Dict, Union
import os

StrPath = Union[str, os.PathLike]
